#
# spec file for package sshguard
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           sshguard
Version:        1.7.1
Release:        bp153.1.16
Summary:        Protect hosts from brute force attacks against ssh
License:        ISC
Group:          Productivity/Networking/Security
Url:            http://www.sshguard.net
Source0:        http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:        sshguard.sysconfig
Source2:        sshguard.service
Source3:        sshguard.init
Source4:        sshguard.whitelist
Source5:        sshguard-journal.service
Source6:        sshguard-journal-tail
# PATCH-FIX-UPSTREAM sshguard-gcc5.patch
Patch0:         sshguard-gcc5.patch
Requires:       openssh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  %fillup_prereq
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%define has_systemd 1
%else
Requires(pre):  %fillup_prereq
%endif

%description
Sshguard protects networked hosts from brute force attacks
against ssh servers. It detects such attacks and blocks the
attacker's address with a firewall rule.

%prep
%setup -q
%patch0 -p1
find . -type f -iname "*.swp" -print -exec rm {} \;

%build
%configure \
  --with-firewall=iptables \
  --with-iptables=%{_sbindir}/iptables
make %{?_smp_mflags}

%install
%make_install
install -D -m0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.sshguard
%if 0%{?has_systemd}
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/sshguard.service
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}-journal
install -D -m0644 %{SOURCE5} %{buildroot}%{_unitdir}/sshguard-journal.service
install -D -m0744 %{SOURCE6} %{buildroot}/%{_sbindir}/sshguard-journal-tail
%else
install -D -m0744 %{SOURCE3} %{buildroot}%{_sysconfdir}/init.d/sshguard
ln -s ../..%{_sysconfdir}/init.d/sshguard %{buildroot}%{_sbindir}/rcsshguard
%endif
install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}
install -D -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}/whitelist
install -d -m0755 %{buildroot}%{_localstatedir}/lib/%{name}/db
%fillup_and_insserv

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%service_add_pre %{name}-journal.service
%endif

%post
%if 0%{?has_systemd}
%fillup_only sshguard
%service_add_post sshguard.service
%service_add_post sshguard-journal.service
%else
%fillup_and_insserv sshguard
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun sshguard.service
%service_del_preun sshguard-journal.service
%else
%stop_on_removal sshguard
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun sshguard.service
%service_del_postun sshguard-journal.service
%else
%restart_on_update sshguard
%insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%doc CHANGELOG.rst README.rst COPYING examples/ doc/
%{_sbindir}/*
%doc %{_mandir}/man8/%{name}*
%{_fillupdir}/sysconfig.sshguard
%if 0%{?has_systemd}
%{_unitdir}/sshguard.service
%{_unitdir}/sshguard-journal.service
%else
%config %{_sysconfdir}/init.d/sshguard
%endif
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/whitelist
%dir %{_localstatedir}/lib/%{name}
%attr(755,root,root) %{_localstatedir}/lib/%{name}/db
%{_libexecdir}/sshg-*

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar  1 2017 joop.boonen@opensuse.org
- Add a systemd journal tail so sshguard can parse this file
* Thu Dec 29 2016 joop.boonen@opensuse.org
- Build version 1.7.1
  - Add sample Mac OS X 10.12 style launchd.plist
  - Allow multiple forward slashes in process name
  - Log released addresses only when debugging
  - Process validation (``-f`` option) is deprecated
  - Adjust TIMESTAMP_ISO8601 for Mac OS X 10.12
  - Fix build error in hosts backend
  - Fix empty functions in firewall scripts causing errors with Bash
  - Flush stdout after every line in sshg-parser
  - Add *sshg-logtail*
  - Add *sshg-parser*
  - Control firewall using *sshg-fw*
  - Match "no matching key exchange method" for SSH
  - Hosts backend is deprecated
  - Logsuck (``-l`` option) is deprecated, use *sshg-logtail* instead
  - Process validation (``-f`` option) is deprecated
  - Remove external hooks (``-e`` option)
  - Remove support for genfilt and ipfilter backends
  - Accept socklog messages without a timestamp
  - Fix excessive logging causing endless looping in logsuck
  - Fix undefined assignment of initial inode number
  - Match Postfix pre-authentication disconnects
  - Fix bashisms in iptables backend
  - Fix size argument in inet_ntop() call
  - Remove excessive logging when polling from files
  - Keep looking for unreadable files while polling
  - Update Dovecot signature for POP3
  - Match "Connection reset" message for SSH
  - Resurrect PID file option by popular demand
  - Adjust default abuse threshold
* Fri Feb 19 2016 joop.boonen@opensuse.org
- Added a corrected attack treshold value (40 default)
* Thu Feb 18 2016 eshmarnev@suse.com
- Build version 1.6.3
  - Disable blacklisting by default
  - Implement logging as wrappers around syslog(2)
  - Improve log and error messages
  - Match sendmail authentication failures
  - Remove PID file option
  - Remove SIGTSTP and SIGCONT handler
  - Remove reverse mapping attack signature
  - Remove safe_fgets() and exit on interrupt
  - Terminate state entries for hosts blocked with pf
  - Update and shorten command-line usage
  - Use 'configure' to set feature-test macros
- Updated patch file for new version of sshguard
* Mon Jan 11 2016 joop.boonen@opensuse.org
- Added ip6tables support handles via init and service files
* Fri Oct 16 2015 joop.boonen@opensuse.org
- Corrected a iptables error, that prevented sshguard
  from functioning correctly
* Thu Oct 15 2015 joop.boonen@opensuse.org
- Moved blacklist.db to /var/lib/sshguard/db/blacklist.db analog
  most SUSE packages
* Thu Oct 15 2015 joop.boonen@opensuse.org
- Corrected the blacklist as it's auto generated
- Improved sysconfig
* Wed Oct 14 2015 joop.boonen@opensuse.org
- Build version 1.6.2
  + Make '-w' option backwards-compatible for iptables (James Harris)
  + Remove support for ip6fw and 'ipfw-range' option
  + Rewrite ipfw backend using command framework
- The white and black list now initially reside in files
  /etc/sshguard/whitelist|blacklist
* Mon Sep 28 2015 joop.boonen@opensuse.org
- Build version 1.6.1
- Added sshguard-gcc5.patch so it also builds via gcc5
- Created a sshguard.service file so it'll run on systemd
  systems
* Wed Mar 27 2013 joop.boonen@opensuse.org
- Reformated the spec file to the openSUSE standard
  so it can be submitted to Factory
* Sat Feb 19 2011 lars@linux-schulserver.de
- update to 1.5:
  + logsucker: sshguard polls multiple log files at once
  + recognize syslog's "last message repeated N times" contextually
    and per-source
  + attackers now gauged with attack *dangerousness* instead of
    count (adjust your -a !)
  + improve IPv6 support
  + add detection for: Exim, vsftpd, Sendmail, Cucipop
  + improve logging granularity and descriptiveness
  + add -i command line option for saving PID file as an aid for
    startup scripts
  + update some attack signatures
- cleanup specfile via spec-cleaner
* Wed Dec  1 2010 wr@rosenauer.org
- fix typo in macro
- revert a bit of cleanup to make it backwards compatible
  (%%_initddir)
* Tue Nov  2 2010 prusnak@opensuse.org
- cleanup spec file
* Wed Sep 29 2010 wr@rosenauer.org
- update to version 1.5rc4
* Sun Apr  4 2010 wr@rosenauer.org
- update to version 1.5rc1
* Thu Feb 11 2010 wr@rosenauer.org
- added init script and sysconfig
* Wed Feb 10 2010 wr@rosenauer.org
- initial openSUSE package
